<?php

namespace Drupal\taxonomy_menu_sync\Drush\Commands;

use Drupal\taxonomy_menu_sync\TaxonomyMenuSyncHelper;
use Drush\Commands\DrushCommands;

/**
 * Handles the drush command for menu sync.
 */
class TaxonomyMenuSyncCommands extends DrushCommands {

  /**
   * @var \Drupal\taxonomy_menu_sync\TaxonomyMenuSyncHelper
   * Menu configuration service.
   */
  protected $taxonomyMenuSyncHelper;

  /**
   * Menu sync drush commands object.
   *
   * @param \Drupal\taxonomy_menu_sync\TaxonomyMenuSyncHelper $taxonomy_menu_sync_helper
   *   Menu configuration service.
   */
  public function __construct(TaxonomyMenuSyncHelper $taxonomy_menu_sync_helper) {
    parent::__construct();
    $this->taxonomyMenuSyncHelper = $taxonomy_menu_sync_helper;
  }

  /**
   * A Drush command to sync taxonomy terms in menu based on provided
   * information.
   *
   * @param string $ids
   *   The lists of comma(,) separated menu configuration ids. (eg: "1,2,3").
   *
   * @command taxonomy_menu_sync:sync
   * @aliases tms:sync
   * @usage taxonomy_menu_sync:sync 1,2,7,9
   *
   * @throws \Exception
   */
  public function sync(string $ids): void {
    if (empty($ids) || empty($ids = explode(',', $ids))) {
      throw new \Exception('You must provide a non-empty array of menu configuration ids.');
    }

    $this->output()->writeln('Synchronization initiated.');
    foreach (array_unique($ids) as $id) {
      $this->taxonomyMenuSyncHelper->sync($id);
    }

    $this->output()->writeln('Synchronization completed.');
  }

}
